==> owncloud-10.0.7.tgz: owncloud/settings/l10n/bn_BD.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ভুল কুটশব্দ",
    "No user supplied" : "ব্যবহারকারী দেয়া হয়নি",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Saved" : "সংরক্ষণ করা হলো",
    "test email settings" : "ইমেইল নিয়ামকসমূহ পরীক্ষা করুন",
    "Email sent" : "ই-মেইল পাঠানো হয়েছে",
    "Your full name has been changed." : "আপনার পূর্ণ নাম পরিবর্তন করা হয়েছে।",
    "__language_name__" : "__language_name__",
    "Language changed" : "ভাষা পরিবর্তন করা হয়েছে",
    "Invalid request" : "অনুরোধটি সঠিক নয়",
    "Admins can't remove themself from the admin group" : "প্রশাসকবৃন্দ তাদেরকে প্রশাসক গোষ্ঠী থেকে মুছে ফেলতে পারবেন না",
    "Unknown user" : "অপরিচিত ব্যবহারকারী",
    "Couldn't remove app." : "অ্যাপ অপসারণ করা গেলনা",
    "All" : "সবাই",
    "Enabled" : "কার্যকর",
    "Error while disabling app" : "অ্যাপ অকার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Disable" : "নিষ্ক্রিয়",
    "Enable" : "সক্রিয় ",
    "Error while enabling app" : "অ্যাপ কার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Updating...." : "নবায়ন করা হচ্ছে....",
    "Error while updating app" : "অ্যাপ নবায়ন করতে সমস্যা দেখা দিয়েছে  ",
    "Updated" : "নবায়নকৃত",
    "Valid until {date}" : "বৈধতা বলবৎ আছে {তারিখ} অবধি ",
    "Delete" : "মুছে",
    "Strong password" : "শক্তিশালী কুটশব্দ",
    "Groups" : "গোষ্ঠীসমূহ",
    "undo" : "ক্রিয়া প্রত্যাহার",
    "never" : "কখনোই নয়",
    "enabled" : "সক্রিয় করা",
    "disabled" : "নিষ্ক্রিয় করা",
    "Cheers!" : "শুভেচ্ছা!",
    "Forum" : "ফোরাম",
    "Sharing" : "ভাগাভাগিরত",
    "Expire after " : "এরপর মেয়াদোত্তীর্ণ হও",
    "days" : "দিনগুলি",
    "Enforce expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ কার্যকর করুন",
    "None" : "কোনটিই নয়",
    "Login" : "প্রবেশ",
    "Send mode" : "পাঠানো মোড",
    "Encryption" : "সংকেতায়ন",
    "From address" : "হইতে ঠিকানা",
    "mail" : "মেইল",
    "Server address" : "সার্ভার ঠিকানা",
    "Port" : "পোর্ট",
    "Send email" : "ইমেইল পাঠান ",
    "Get the apps to sync your files" : "আপনার ফাইলসমূহ সিংক করতে অ্যাপস নিন",
    "Show First Run Wizard again" : "প্রথমবার চালানোর যাদুকর পূনরায় প্রদর্শন কর",
    "Cancel" : "বাতির",
    "Email" : "ইমেইল",
    "Your email address" : "আপনার ই-মেইল ঠিকানা",
    "Password" : "কূটশব্দ",
    "Unable to change your password" : "আপনার কূটশব্দটি পরিবর্তন করতে সক্ষম নয়",
    "Current password" : "বর্তমান কূটশব্দ",
    "New password" : "নতুন কূটশব্দ",
    "Change password" : "কূটশব্দ পরিবর্তন করুন",
    "Language" : "ভাষা",
    "Help translate" : "অনুবাদ করতে সহায়তা করুন",
    "Unlimited" : "অসীম",
    "Name" : "নাম",
    "Username" : "ব্যবহারকারী",
    "Done" : "শেষ হলো",
    "Version" : "ভার্সন",
    "Personal" : "ব্যক্তিগত",
    "Admin" : "প্রশাসন",
    "Error" : "সমস্যা",
    "Create" : "তৈরী কর",
    "Admin Recovery Password" : "প্রশাসক পূণরূদ্ধার কুটশব্দ",
    "Add Group" : "গ্রুপ যোগ কর",
    "Group" : "গোষ্ঠীসমূহ",
    "Everyone" : "সকলে",
    "Admins" : "প্রশাসন",
    "Other" : "অন্যান্য",
    "Quota" : "কোটা",
    "Storage Location" : "সংরক্ষণাগার এর অবস্থান",
    "Last Login" : "শেষ লগইন",
    "change full name" : "পুরোনাম পরিবর্তন করুন",
    "set new password" : "নতুন কূটশব্দ নির্ধারণ করুন",
    "Default" : "পূর্বনির্ধারিত"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/settings/l10n/bn_BD.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ভুল কুটশব্দ",
    "No user supplied" : "ব্যবহারকারী দেয়া হয়নি",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Saved" : "সংরক্ষণ করা হলো",
    "test email settings" : "ইমেইল নিয়ামকসমূহ পরীক্ষা করুন",
    "Email sent" : "ই-মেইল পাঠানো হয়েছে",
    "Your full name has been changed." : "আপনার পূর্ণ নাম পরিবর্তন করা হয়েছে।",
    "__language_name__" : "__language_name__",
    "Language changed" : "ভাষা পরিবর্তন করা হয়েছে",
    "Invalid request" : "অনুরোধটি সঠিক নয়",
    "Admins can't remove themself from the admin group" : "প্রশাসকবৃন্দ তাদেরকে প্রশাসক গোষ্ঠী থেকে মুছে ফেলতে পারবেন না",
    "Unknown user" : "অপরিচিত ব্যবহারকারী",
    "Couldn't remove app." : "অ্যাপ অপসারণ করা গেলনা",
    "All" : "সবাই",
    "Enabled" : "কার্যকর",
    "Error while disabling app" : "অ্যাপ অকার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Disable" : "নিষ্ক্রিয়",
    "Enable" : "সক্রিয় ",
    "Error while enabling app" : "অ্যাপ কার্যকর করতে সমস্যা দেখা দিয়েছে  ",
    "Updating...." : "নবায়ন করা হচ্ছে....",
    "Error while updating app" : "অ্যাপ নবায়ন করতে সমস্যা দেখা দিয়েছে  ",
    "Updated" : "নবায়নকৃত",
    "Valid until {date}" : "বৈধতা বলবৎ আছে {তারিখ} অবধি ",
    "Delete" : "মুছে",
    "Strong password" : "শক্তিশালী কুটশব্দ",
    "Groups" : "গোষ্ঠীসমূহ",
    "undo" : "ক্রিয়া প্রত্যাহার",
    "never" : "কখনোই নয়",
    "enabled" : "সক্রিয় করা",
    "disabled" : "নিষ্ক্রিয় করা",
    "Cheers!" : "শুভেচ্ছা!",
    "Forum" : "ফোরাম",
    "Sharing" : "ভাগাভাগিরত",
    "Expire after " : "এরপর মেয়াদোত্তীর্ণ হও",
    "days" : "দিনগুলি",
    "Enforce expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ কার্যকর করুন",
    "None" : "কোনটিই নয়",
    "Login" : "প্রবেশ",
    "Send mode" : "পাঠানো মোড",
    "Encryption" : "সংকেতায়ন",
    "From address" : "হইতে ঠিকানা",
    "mail" : "মেইল",
    "Server address" : "সার্ভার ঠিকানা",
    "Port" : "পোর্ট",
    "Send email" : "ইমেইল পাঠান ",
    "Get the apps to sync your files" : "আপনার ফাইলসমূহ সিংক করতে অ্যাপস নিন",
    "Show First Run Wizard again" : "প্রথমবার চালানোর যাদুকর পূনরায় প্রদর্শন কর",
    "Cancel" : "বাতির",
    "Email" : "ইমেইল",
    "Your email address" : "আপনার ই-মেইল ঠিকানা",
    "Password" : "কূটশব্দ",
    "Unable to change your password" : "আপনার কূটশব্দটি পরিবর্তন করতে সক্ষম নয়",
    "Current password" : "বর্তমান কূটশব্দ",
    "New password" : "নতুন কূটশব্দ",
    "Change password" : "কূটশব্দ পরিবর্তন করুন",
    "Language" : "ভাষা",
    "Help translate" : "অনুবাদ করতে সহায়তা করুন",
    "Unlimited" : "অসীম",
    "Name" : "নাম",
    "Username" : "ব্যবহারকারী",
    "Done" : "শেষ হলো",
    "Version" : "ভার্সন",
    "Personal" : "ব্যক্তিগত",
    "Admin" : "প্রশাসন",
    "Error" : "সমস্যা",
    "Create" : "তৈরী কর",
    "Admin Recovery Password" : "প্রশাসক পূণরূদ্ধার কুটশব্দ",
    "Add Group" : "গ্রুপ যোগ কর",
    "Group" : "গোষ্ঠীসমূহ",
    "Everyone" : "সকলে",
    "Admins" : "প্রশাসন",
    "Other" : "অন্যান্য",
    "Quota" : "কোটা",
    "Storage Location" : "সংরক্ষণাগার এর অবস্থান",
    "Last Login" : "শেষ লগইন",
    "change full name" : "পুরোনাম পরিবর্তন করুন",
    "set new password" : "নতুন কূটশব্দ নির্ধারণ করুন",
    "Default" : "পূর্বনির্ধারিত",
    "Share" : "ভাগাভাগি কর",
    "Add" : "যোগ কর"
},
"nplurals=2; plural=(n != 1);");
